/**
 * Copyright (C) 2008 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.guicerecipes.jndi;

import java.lang.annotation.*;

import com.google.inject.*;

import static java.lang.annotation.ElementType.*;
import static java.lang.annotation.RetentionPolicy.*;

/**
 * Marks an injection point so that it is bound to the current JNDI context with some JNDI name
 * 
 * @version $Revision: 1.1 $
 */
@Target( { METHOD, CONSTRUCTOR, FIELD, TYPE })
@Retention(RUNTIME)
@Documented
@BindingAnnotation
public @interface JndiBind {

	/**
	 * The JNDI name to bind the value to
	 * 
	 * @return the name to bind the value to in JNDI
	 */
	public String value();
}
